


clear all
clear matrix
set more off
set mem 1200m
set matsize 10000



global path ""
cd "$path"

cap log close
log using "bases_replication2.log", replace 



tempfile tfile1



/////////// FIGURES 


********************************************************
* FIGURE Appendx 1 and Figure 1 Panel A: THE INSTRUMENT  
*********************************************************

use "bases_replication.dta", clear
#delimit ;
keep year lrmilnar_col lrmilwnl paratt  gueratt govatt year bases6xyear bases6xyearxpost2000 bases6xyearxpost2001i lnnewpop municipality 
bases6xlcolmilexp_2000_bnusd gaviriaxbases6 samperxbases6 pastranaxbases6 uribexbases6 department sample
captives bases6xlrmilnar_col weaponsops frkid  coca operation_antinarcotics bases6xlrnar_col bases6xlrmilnar_col pGUERpres 
bases6xlrnar_col bases6xlrmil_col PAR_tot_hom bases6xlrmncxely bases6xlrmilnar_col bases6xely GUER_tot_hom  bases6xpost2001i
PAR_political_homicide GUER_political_homicide bases6xlrmworxely bases6xlrmilwnl gp0003mediboth coca meanslopexlrmilnar_col
newpop captives weaponsops frkid operation_antinarcotics sumtotcas7587v2_pop88 stdheight meanheight evercoca coca00 oil gp0003mediboth 
bases6 rmilnar_col rmil_col rnar_col rmil_world_nolac rnar_world_nolac colmilexp_2000_bnusd bases6xlrnarwnl
lrmilnar_col lrmil_col lrnar_col lrmilwnl  lrnarwnl lmilexp yearsq bases6xlrmil_col bases6xlrmilnar_col paratt_ind
DELpres8890 borbases6 borbases6v2 sumgueratt7587v2_pop88 urban88 coca00 oil evercoca meanslopexlwnl meanslope endogbaseonly endogbaseexpxpost2001; 
#delimit cr

save "bases_replication_final.dta", replace
use "bases_replication_final.dta", clear
preserve

	
		table year if year<=2005, c(mean lrmilnar_col mean lrmilwnl)
		collapse (mean) lrmilnar_col lrmilwnl paratt gueratt govatt, by(year)
		label var lrmilnar_col "Log Military and Narcotics Aid to Colombia"
		label var lrmilwnl "Log Military Aid to Non-LAC Countries"
		tsset year
		#delimit ;
		graph twoway (tsline lrmilnar_col, lwidth(thick) lcolor(red)
		lpattern(dash) yaxis(1)  )
		(tsline lrmilwnl, saving("fig2a",replace) 
		lwidth(thick) lcolor(green) legend( rows(2)) tlabel(1988(2)2005) 
		graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) yaxis(2))
		
		;
		#delimit cr
		graph export "figappendix1.png",replace
		
		label var paratt  "Paramilitary Attacks"
		label var gueratt "Guerrilla  Attacks"
		label var govatt  "Government  Attacks"
				
		#delimit ;
		graph twoway (tsline paratt gueratt govatt, tlabel(1988(2)2005)  saving("fig1",replace) 
		lwidth(thick thick thick) lcolor(black red blue) lpattern(solid dash dash_dot)  legend( rows(3)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) yaxis(2))
		;
		#delimit cr
		graph export "fig1panela.png",replace
		
		keep lrmilnar_col year
		sort year
		save `tfile1', replace
restore		



**************************************************
* FIGURE 1 Panel B: THE YEAR INTERACTIONS GRAPH
**************************************************
preserve

levelsof(year), local(t)
foreach ti in `t'{
if `ti' !=1988{
	gen bases6Xyear`ti' = bases6*(year==`ti')
}
}
xi: xtivreg2  paratt  bases6Xyear*  i.year lnnewpop if sample==1, cluster(municipality) fe 
parmest, saving("yearXbaseeffects_dec_11_2013.dta", replace)
		use "yearXbaseeffects_dec_11_2013.dta", clear
		keep if regexm(parm,"bases6Xyear")
		drop if regexm(parm,"^o\.")
		
		keep parm estimate min95 max95
		gen year=1988
		forvalues i=1988/2005{
			replace year =`i' if parm=="bases6Xyear`i'"
		}
		drop if parm==""
		sort year
		merge year using `tfile1'
		replace estimate =0 if year==1988
		replace min95 =0 if year==1988
		replace max95 =0 if year==1988
		sort year
		
		label var estimate "Coefficient on Base Municipality (DV= Paramilitary Attacks)"
		#delimit ;
			twoway 
			(line lrmilnar_col year, lcolor(red) lpattern(dash_dot) lwidth(thick) yaxis(2) ytitle("")) 
				(line estimate year, lcolor(black) lwidth(thick) xline(0)
				title("Estimates of Coefficients (relative to 1988) ", size(small))
				xlabel(1988(2)2005) 
				xtitle("")
				ytitle("")
				legend(order(1 2) rows(2))
				
				graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
				plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) yaxis(1))
			;
		#delimit cr
		graph export "fig1panelb.png",replace

restore


/////////////  Appendix Figure 2 T-tests 		

levelsof(municipality) if bases6==1, local(basemunis)
gen coefs=.
gen beta=.
local n=1
foreach base in `basemunis'{

xi: xtivreg2  paratt  bases6xlrmilnar_col i.year lnnewpop if sample==1 & municipality!=`base', cluster(municipality) fe 
replace coefs=_b[bases6xlrmilnar_col]/_se[bases6xlrmilnar_col] if _n==`n'
        replace beta = _b[bases6xlrmilnar_col] if _n==`n'
local n = `n'+1
}

duplicates drop coefs,force
sum coef, d 
sum beta,d

hist coefs, xtitle("T-statistic on coefficient estimated from sample omitting each base") graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export figappendix2.png, replace




/////////////  MAIN  TABLES 


use  "bases_replication_final.dta", clear

*cd "C:\Users\Oeindrila Dube\Documents\0Colombia_pc\140617_replication"

********************************
* Table 1: OLS and IV on attacks - BASELINE SPEC
********************************

* OLS on attacks
	xi: xtivreg2  paratt   bases6xlrmilnar_col lnnewpop i.year , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE1.csv, replace se  bdec(3) tdec(3) nocons br
	foreach var of varlist  govatt   gueratt      {
	xi: xtivreg2  `var' bases6xlrmilnar_col lnnewpop i.year, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE1.csv, append se  bdec(3) tdec(3) nocons br
	}

	xi: xtivreg2  paratt   bases6xlrmilnar_col lnnewpop i.year if year~=2000, cluster(municipality) fe 

* IV usmil nolac as instrument 

	xi: xtivreg2  paratt   (bases6xlrmilnar_col=bases6xlrmilwnl) lnnewpop i.year, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE1.csv, append se br  bdec(3) tdec(3) nocons 
	foreach var of varlist   govatt   gueratt    {
	xi: xtivreg2  `var' (bases6xlrmilnar_col=bases6xlrmilwnl) lnnewpop i.year, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE1.csv,  append se br  bdec(3) tdec(3) nocons 
	}

* IV usmil nolac in reduced form 

capture confirm file TABLE1.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE1.csv
    }

	xi: xtivreg2  paratt   bases6xlrmilwnl lnnewpop i.year , cluster(municipality) fe 
	outreg2 bases6xlrmilwnl  using  TABLE1.csv,  append se br  bdec(3) tdec(3) nocons 
	foreach var of varlist   govatt   gueratt       {
	xi: xtivreg2  `var' bases6xlrmilwnl lnnewpop i.year, cluster(municipality) fe 
	outreg2 bases6xlrmilwnl  using  TABLE1.csv,  append se br  bdec(3) tdec(3) nocons 
	}

	
	
		
****************************************
* Table 2: OLS and IV  -   with controls
****************************************

/// PANEL A - OLS


	* Controlling for  govatt  
	xi: xtivreg2  paratt    bases6xlrmilnar_col  govatt    lnnewpop i.year , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col govatt   using TABLE2A.csv, replace se  bdec(3) tdec(3) nocons br
	foreach var of varlist    gueratt   {
	xi: xtivreg2  `var' bases6xlrmilnar_col  govatt   lnnewpop i.year , cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col govatt    using TABLE2A.csv, append se  bdec(3) tdec(3) nocons br
	}
	xi  i.department*i.year, prefix(_D)
	
	* Department trends
	tsset municipality year, yearly
	xi: xtivreg2  paratt   bases6xlrmilnar_col _D* lnnewpop, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE2A.csv, append se br  bdec(3) tdec(3) nocons 
	foreach var of varlist   govatt   gueratt    {
	xi: xtivreg2  `var' bases6xlrmilnar_col _D* lnnewpop, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE2A.csv, append se br  bdec(3) tdec(3) nocons 
	}

capture confirm file TABLE2A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE2A.csv
    }
	
	* Trends by base region and controlling for post-2001
	xi: xtivreg2  paratt    bases6xlrmilnar_col bases6xyear  bases6xpost2001i lnnewpop i.year , cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE2A.csv, append se  bdec(3) tdec(3) nocons br 
	foreach var of varlist   govatt   gueratt    {
	xi: xtivreg2  `var'  bases6xlrmilnar_col  bases6xyear  bases6xpost2001i  lnnewpop i.year , cluster(municipality) fe 
	outreg2    bases6xlrmilnar_col   using TABLE2A.csv, append se  bdec(3) tdec(3) nocons br
	}
	
	capture confirm file TABLE2A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE2A.csv
    }
	* Other time varying controls 
	xi: xtivreg2  paratt    bases6xlrmilnar_col  i.year*sumgueratt7587v2_pop88 i.year*sumtotcas7587v2_pop88 i.year*urban88 i.year*coca00 i.year*stdheight i.year*oil lnnewpop i.year , cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE2A.csv, append se  bdec(3) tdec(3) nocons br 
	foreach var of varlist   govatt   gueratt    {
	xi: xtivreg2  `var'  bases6xlrmilnar_col  i.year*sumgueratt7587v2_pop88 i.year*sumtotcas7587v2_pop88 i.year*urban88 i.year*coca00 i.year*stdheight i.year*oil  lnnewpop i.year , cluster(municipality) fe 
	outreg2    bases6xlrmilnar_col   using TABLE2A.csv, append se  bdec(3) tdec(3) nocons br
	}
	
/// Panel B -  IV 

* xi  i.department*i.year, prefix(_D)

	* Controlling for  govatt  
	xi: xtivreg2  paratt    (bases6xlrmilnar_col=bases6xlrmilwnl) govatt    lnnewpop i.year , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col govatt   using TABLE2B.csv, replace se  bdec(3) tdec(3) nocons br
	foreach var of varlist    gueratt   {
	xi: xtivreg2  `var'  (bases6xlrmilnar_col=bases6xlrmilwnl)  govatt   lnnewpop i.year , cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col govatt    using TABLE2B.csv, append se  bdec(3) tdec(3) nocons br
	}

	capture confirm file TABLE2B.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE2B.csv
    }
	
	
	* Department trends 
	tsset municipality year, yearly
	xi: xtivreg2  paratt   (bases6xlrmilnar_col=bases6xlrmilwnl)  _D* lnnewpop, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE2B.csv, append  se br  bdec(3) tdec(3) nocons 
	foreach var of varlist   govatt   gueratt    {
	xi: xtivreg2  `var'  (bases6xlrmilnar_col=bases6xlrmilwnl) _D* lnnewpop, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE2B.csv, append se br  bdec(3) tdec(3) nocons 
	}

	capture confirm file TABLE2B.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE2B.csv
    }
	* Trends by base region and controlling for post-2001
	xi: xtivreg2  paratt    (bases6xlrmilnar_col=bases6xlrmilwnl)  bases6xyear  bases6xpost2001i lnnewpop i.year , cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE2B.csv, append se  bdec(3) tdec(3) nocons br 
	foreach var of varlist   govatt   gueratt    {
	xi: xtivreg2  `var'  (bases6xlrmilnar_col=bases6xlrmilwnl)  bases6xyear  bases6xpost2001i  lnnewpop i.year , cluster(municipality) fe 
	outreg2    bases6xlrmilnar_col   using TABLE2B.csv, append se  bdec(3) tdec(3) nocons br
	}
	capture confirm file TABLE2B.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE2B.csv
    }
	* Other time varying controls 
	xi: xtivreg2  paratt    (bases6xlrmilnar_col=bases6xlrmilwnl) i.year*sumgueratt7587v2_pop88 i.year*sumtotcas7587v2_pop88 i.year*urban88 i.year*coca00 i.year*stdheight i.year*oil lnnewpop i.year , cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE2B.csv, append se  bdec(3) tdec(3) nocons br 
	foreach var of varlist   govatt   gueratt    {
	xi: xtivreg2  `var'  (bases6xlrmilnar_col=bases6xlrmilwnl) i.year*sumgueratt7587v2_pop88 i.year*sumtotcas7587v2_pop88 i.year*urban88 i.year*coca00 i.year*stdheight i.year*oil  lnnewpop i.year , cluster(municipality) fe 
	outreg2    bases6xlrmilnar_col   using TABLE2B.csv, append se  bdec(3) tdec(3) nocons br
	}

	

 
****************************************
* Table 3: accounting for state strength
****************************************

	
	*** Military expenditures: OLS
	xi: xtivreg2  paratt    bases6xlrmilnar_col  bases6xlcolmilexp_2000_bnusd lnnewpop i.year , cluster(municipality) fe 
	lincom bases6xlrmilnar_col + bases6xlcolmilexp_2000_bnusd  
	outreg2 bases6xlrmilnar_col bases6xlcolmilexp_2000_bnusd using TABLE3.csv, replace se  bdec(3) tdec(3) nocons br
	foreach var of varlist  govatt   gueratt   {
		capture confirm file TABLE3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE3.csv
    }
	
	xi: xtivreg2  `var' bases6xlrmilnar_col  bases6xlcolmilexp_2000_bnusd lnnewpop i.year , cluster(municipality) fe 
	lincom bases6xlrmilnar_col + bases6xlcolmilexp_2000_bnusd  
	outreg2  bases6xlrmilnar_col bases6xlcolmilexp_2000_bnusd using TABLE3.csv, append se  bdec(3) tdec(3) nocons br
	}
		capture confirm file TABLE3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE3.csv
    }
	
	*** Military expenditures:  IV
	xi: xtivreg2  paratt    (bases6xlrmilnar_col=bases6xlrmilwnl)  bases6xlcolmilexp_2000_bnusd lnnewpop i.year , cluster(municipality) fe 
	lincom bases6xlrmilnar_col + bases6xlcolmilexp_2000_bnusd  
	outreg2 bases6xlrmilnar_col bases6xlcolmilexp_2000_bnusd using TABLE3.csv, append se  bdec(3) tdec(3) nocons br
	foreach var of varlist  govatt   gueratt   {
			capture confirm file TABLE3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE3.csv
    }
	xi: xtivreg2  `var'  (bases6xlrmilnar_col=bases6xlrmilwnl)  bases6xlcolmilexp_2000_bnusd lnnewpop i.year , cluster(municipality) fe 
	lincom bases6xlrmilnar_col + bases6xlcolmilexp_2000_bnusd  
	outreg2  bases6xlrmilnar_col bases6xlcolmilexp_2000_bnusd using TABLE3.csv, append se  bdec(3) tdec(3) nocons br
	}
			capture confirm file TABLE3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE3.csv
    }
	
	*** Control for all pres effects separately:  OLS
	xi: xtivreg2  paratt   bases6xlrmilnar_col gaviriaxbases6 samperxbases6 pastranaxbases6 uribexbases6  lnnewpop i.year, cluster(municipality) fe first
	outreg2 bases6xlrmilnar_col  gaviriaxbases6 samperxbases6 pastranaxbases6 uribexbases6  using TABLE3.csv,  append se br  bdec(3) tdec(3) nocons 
	foreach var of varlist  govatt   gueratt    {
			capture confirm file TABLE3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE3.csv
    }
	xi: xtivreg2  `var' bases6xlrmilnar_col  gaviriaxbases6 samperxbases6 pastranaxbases6 uribexbases6  lnnewpop i.year, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col gaviriaxbases6 samperxbases6 pastranaxbases6 uribexbases6  using  TABLE3.csv, append se br  bdec(3) tdec(3) nocons 
	}

	*** Control for all pres effects separately:  IV
	xi: xtivreg2  paratt   (bases6xlrmilnar_col=bases6xlrmilwnl) gaviriaxbases6 samperxbases6 pastranaxbases6 uribexbases6  lnnewpop i.year, cluster(municipality) fe first
	outreg2 bases6xlrmilnar_col  gaviriaxbases6 samperxbases6 pastranaxbases6 uribexbases6  using TABLE3.csv, append se br  bdec(3) tdec(3) nocons 
	foreach var of varlist  govatt   gueratt    {
			capture confirm file TABLE3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE3.csv
    }
	xi: xtivreg2  `var' (bases6xlrmilnar_col=bases6xlrmilwnl)  gaviriaxbases6 samperxbases6 pastranaxbases6 uribexbases6  lnnewpop i.year, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col gaviriaxbases6 samperxbases6 pastranaxbases6 uribexbases6  using  TABLE3.csv, append se br  bdec(3) tdec(3) nocons 
	}


******************************************
* Table 4: OLS on enforcement and coca
******************************************

/// OLS

*  military and narcotics aid together 
	xi: xtivreg2   captives bases6xlrmilnar_col lnnewpop i.year if coca~=. , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE4A.csv, replace se  bdec(3) tdec(3) nocons br
	foreach var of varlist weaponsops frkid   coca operation_antinarcotics {
			capture confirm file TABLE4A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4A.csv
    }
	xi: xtivreg2  `var' bases6xlrmilnar_col lnnewpop i.year if coca~=., cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE4A.csv, append se  bdec(3) tdec(3) nocons br
	}
	xi: xtivreg2   operation_antinarcotics  bases6xlrmilnar_col lnnewpop i.year if coca~=. & evercoca==1 , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE4A.csv, append se  bdec(3) tdec(3) nocons br
			capture confirm file TABLE4A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4A.csv
    }

*   just narcotics aid
	xi: xtivreg2   captives  bases6xlrnar_col lnnewpop i.year if coca~=. , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4A.csv,  append se  bdec(3) tdec(3) nocons br
	foreach var of varlist weaponsops frkid   coca operation_antinarcotics {
				capture confirm file TABLE4A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4A.csv
    }
	xi: xtivreg2  `var'  bases6xlrnar_col  lnnewpop i.year if coca~=., cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4A.csv, append se  bdec(3) tdec(3) nocons br
	}
	xi: xtivreg2   operation_antinarcotics  bases6xlrnar_col lnnewpop i.year if coca~=. & evercoca==1 , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4A.csv, append se  bdec(3) tdec(3) nocons br
			capture confirm file TABLE4A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4A.csv
    }

*   just military aid
	xi: xtivreg2   captives bases6xlrmil_col lnnewpop i.year if coca~=. , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4A.csv, append se  bdec(3) tdec(3) nocons br
	foreach var of varlist weaponsops frkid   coca operation_antinarcotics {
				capture confirm file TABLE4A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4A.csv
    }
	xi: xtivreg2  `var' bases6xlrmil_col  lnnewpop i.year if coca~=., cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4A.csv, append se  bdec(3) tdec(3) nocons br
	}
				capture confirm file TABLE4A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4A.csv
    }
	xi: xtivreg2   operation_antinarcotics  bases6xlrmil_col lnnewpop i.year if coca~=. & evercoca==1 , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4A.csv, append se  bdec(3) tdec(3) nocons br


/// IV

* military and narcotics aid together with mil instrument 

	xi: xtivreg2   captives (bases6xlrmilnar_col=bases6xlrmilwnl) lnnewpop i.year if coca~=. , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE4B.csv, replace se  bdec(3) tdec(3) nocons br
	foreach var of varlist weaponsops frkid   coca operation_antinarcotics {
				capture confirm file TABLE4B.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4B.csv
    }
	xi: xtivreg2  `var' (bases6xlrmilnar_col=bases6xlrmilwnl)  lnnewpop i.year if coca~=., cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE4B.csv, append se  bdec(3) tdec(3) nocons br
	}
					capture confirm file TABLE4B.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4B.csv
    }
	xi: xtivreg2   operation_antinarcotics  (bases6xlrmilnar_col=bases6xlrmilwnl)  lnnewpop i.year if coca~=. & evercoca==1 , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE4B.csv, append se  bdec(3) tdec(3) nocons br


* just narcotics aid

	xi: xtivreg2   captives  (bases6xlrnar_col=bases6xlrnarwnl) lnnewpop i.year if coca~=. , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4B.csv,  append se  bdec(3) tdec(3) nocons br
	foreach var of varlist weaponsops frkid   coca operation_antinarcotics {
					capture confirm file TABLE4B.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4B.csv
    }
	xi: xtivreg2  `var'  (bases6xlrnar_col=bases6xlrnarwnl)  lnnewpop i.year if coca~=., cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4B.csv, append se  bdec(3) tdec(3) nocons br
	}
					capture confirm file TABLE4B.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4B.csv
    }
	xi: xtivreg2   operation_antinarcotics (bases6xlrnar_col=bases6xlrnarwnl) lnnewpop i.year if coca~=. & evercoca==1 , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4B.csv, append se  bdec(3) tdec(3) nocons br


* just military aid

	xi: xtivreg2   captives (bases6xlrmil_col=bases6xlrmilwnl) lnnewpop i.year if coca~=. , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4B.csv, append se  bdec(3) tdec(3) nocons br
	foreach var of varlist weaponsops frkid   coca operation_antinarcotics {
					capture confirm file TABLE4B.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4B.csv
    }
	xi: xtivreg2  `var' (bases6xlrmil_col=bases6xlrmilwnl)  lnnewpop i.year if coca~=., cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4B.csv, append se  bdec(3) tdec(3) nocons br
	}				
					capture confirm file TABLE4B.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE4B.csv
    }
	xi: xtivreg2   operation_antinarcotics  (bases6xlrmil_col=bases6xlrmilwnl) lnnewpop i.year if coca~=. & evercoca==1 , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  bases6xlrmil_col  bases6xlrnar_col using TABLE4B.csv, append se  bdec(3) tdec(3) nocons br



******************************************
* Table 5: political homicides(ols and iv)
******************************************


	* OLS 3-way interaction effect  homicides 
	xi: xtivreg2 PAR_tot_hom  lnnewpop i.year bases6xlrmncxely bases6xlrmilnar_col bases6xely , fe cluster(municipality)
	outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5A.csv, replace se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5A.csv
    }
	xi: xtivreg2 GUER_tot_hom  lnnewpop i.year bases6xlrmncxely bases6xlrmilnar_col bases6xely , fe cluster(municipality)
	outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5A.csv, append se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5A.csv
    }
	* IV 3-way interaction effect  homicides 
	xi: xtivreg2  PAR_tot_hom lnnewpop i.year (bases6xlrmncxely bases6xlrmilnar_col= bases6xlrmworxely bases6xlrmilwnl) bases6xely , fe cluster(municipality)
	outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5A.csv, append se br  bdec(3) tdec(3) nocons 
	foreach var of varlist GUER_tot_hom  {
						capture confirm file TABLE5A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5A.csv
    }
	xi: xtivreg2  `var'  lnnewpop i.year (bases6xlrmncxely bases6xlrmilnar_col= bases6xlrmworxely bases6xlrmilwnl) bases6xely,  fe cluster(municipality)
	outreg2 bases6xlrmncxely  bases6xlrmilnar_col bases6xely using TABLE5A.csv, append se br  bdec(3) tdec(3) nocons 
	}
					capture confirm file TABLE5A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5A.csv
    }
	* OLS on assassinations
	xi: xtivreg2 PAR_political_homicide   lnnewpop i.year bases6xlrmncxely bases6xlrmilnar_col bases6xely , fe cluster(municipality)
	outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5A.csv, append se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5A.csv
    }
	xi: xtivreg2 GUER_political_homicide lnnewpop i.year bases6xlrmncxely bases6xlrmilnar_col bases6xely , fe cluster(municipality)
	outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5A.csv, append se br  bdec(3) tdec(3) nocons 

						capture confirm file TABLE5A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5A.csv
    }
	* IV on assassinations
	xi: xtivreg2  PAR_political_homicide lnnewpop i.year (bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely , fe cluster(municipality)
	outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5A.csv, append se br  bdec(3) tdec(3) nocons 
	foreach var of varlist GUER_political_homicide {
						capture confirm file TABLE5A.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5A.csv
    }
	
	xi: xtivreg2  `var'  lnnewpop i.year (bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely,  fe cluster(municipality)
	outreg2 bases6xlrmncxely  bases6xlrmilnar_col bases6xely using TABLE5A.csv, append se br  bdec(3) tdec(3) nocons 
	}



*  HETEROGENEOUS EFFECTS BASED ON POLITICAL COMPETITION 

cap erase  TABLE5B_OLS.csv
cap erase  TABLE5B_OLS.txt

/// OLS

		xi: xtivreg2   PAR_tot_hom  lnnewpop i.year ///
		bases6xlrmncxely bases6xlrmilnar_col bases6xely  ///
		if gp0003mediboth==1 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using  TABLE5B_OLS.csv,   se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5B_OLS.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5B_OLS.csv
    }
		
		
		xi: xtivreg2   GUER_tot_hom  lnnewpop i.year ///
		bases6xlrmncxely bases6xlrmilnar_col bases6xely  ///
		if gp0003mediboth==1 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using  TABLE5B_OLS.csv,   se br  bdec(3) tdec(3) nocons 

					capture confirm file TABLE5B_OLS.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5B_OLS.csv
    }	
	
		xi: xtivreg2  PAR_tot_hom  lnnewpop i.year ///
		bases6xlrmncxely bases6xlrmilnar_col bases6xely    ///
		if gp0003mediboth==0 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5B_OLS.csv,  se br  bdec(3) tdec(3) nocons	
					capture confirm file TABLE5B_OLS.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5B_OLS.csv
    }	
	
		xi: xtivreg2  GUER_tot_hom  lnnewpop i.year ///
		bases6xlrmncxely bases6xlrmilnar_col bases6xely    ///
		if gp0003mediboth==0 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5B_OLS.csv,  se br  bdec(3) tdec(3) nocons	
					capture confirm file TABLE5B_OLS.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5B_OLS.csv
    }	
	
		xi: xtivreg2   PAR_political_homicide  lnnewpop i.year ///
		bases6xlrmncxely bases6xlrmilnar_col bases6xely  ///
		if gp0003mediboth==1 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using  TABLE5B_OLS.csv,   se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5B_OLS.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5B_OLS.csv
    }
	
		xi: xtivreg2   GUER_political_homicide  lnnewpop i.year ///
		bases6xlrmncxely bases6xlrmilnar_col bases6xely  ///
		if gp0003mediboth==1 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using  TABLE5B_OLS.csv,   se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5B_OLS.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5B_OLS.csv
    }
	
		xi: xtivreg2  PAR_political_homicide  lnnewpop i.year ///
		bases6xlrmncxely bases6xlrmilnar_col bases6xely    ///
		if gp0003mediboth==0 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5B_OLS.csv,  se br  bdec(3) tdec(3) nocons	
					capture confirm file TABLE5B_OLS.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5B_OLS.csv
    }
	
		xi: xtivreg2  GUER_political_homicide  lnnewpop i.year ///
		bases6xlrmncxely bases6xlrmilnar_col bases6xely    ///
		if gp0003mediboth==0 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5B_OLS.csv,  se br  bdec(3) tdec(3) nocons	
	

///  IV
	
cap erase  TABLE5C_IV.csv
cap erase  TABLE5C_IV.txt

		xi: xtivreg2  PAR_tot_hom lnnewpop i.year ///
		(bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely  ///
		if gp0003mediboth==1 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using  TABLE5C_IV.csv,   se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5C_IV.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5C_IV.csv
    }
		
		xi: xtivreg2  GUER_tot_hom lnnewpop i.year ///
		(bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely  ///
		if gp0003mediboth==1 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using  TABLE5C_IV.csv,   se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5C_IV.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5C_IV.csv
	}	
		xi: xtivreg2  PAR_tot_hom  lnnewpop i.year ///
		(bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely    ///
		if gp0003mediboth==0 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5C_IV.csv,  se br  bdec(3) tdec(3) nocons	
					capture confirm file TABLE5C_IV.csv
	
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5C_IV.csv	
	}
	
		xi: xtivreg2  GUER_tot_hom  lnnewpop i.year ///
		(bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely    ///
		if gp0003mediboth==0 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5C_IV.csv,  se br  bdec(3) tdec(3) nocons	
					capture confirm file TABLE5C_IV.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5C_IV.csv	
		}
		
		xi: xtivreg2  PAR_political_homicide lnnewpop i.year ///
		(bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely  ///
		if gp0003mediboth==1 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using  TABLE5C_IV.csv,   se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5C_IV.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5C_IV.csv
		}
		
		xi: xtivreg2  GUER_political_homicide lnnewpop i.year ///
		(bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely  ///
		if gp0003mediboth==1 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using  TABLE5C_IV.csv,   se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE5C_IV.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE5C_IV.csv
		}
		
		xi: xtivreg2  PAR_political_homicide lnnewpop i.year ///
		(bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely    ///
		if gp0003mediboth==0 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5C_IV.csv,  se br  bdec(3) tdec(3) nocons	
					capture confirm file TABLE5C_IV.csv
    while _rc {      /* file does not exist! */
		}
		
        capture confirm file TABLE5C_IV.csv		
		xi: xtivreg2  GUER_political_homicide  lnnewpop i.year ///
		(bases6xlrmncxely bases6xlrmilnar_col=bases6xlrmworxely bases6xlrmilwnl) bases6xely    ///
		if gp0003mediboth==0 , fe cluster(municipality)
		lincom bases6xlrmncxely + bases6xlrmilnar_col
		outreg2 bases6xlrmncxely    bases6xlrmilnar_col bases6xely  using TABLE5C_IV.csv,  se br  bdec(3) tdec(3) nocons	
		
	
	
/////////////  APPENDIX  TABLES 





******************
* Appendix table 1
******************

	
	* Time series between military aid to Colombia to countries outside Latin America -  first stage w trends
	reg  lrmilnar_col lrmilwnl if municipality==5001
		outreg2 lrmilwnl using TABLE_APPENDIX_A1_PanelA.csv, replace se br  bdec(3) tdec(3) nocons 
		
					capture confirm file TABLE_APPENDIX_A1_PanelA.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelA.csv
		}
		
	reg  lrmilnar_col lrmilwnl year if municipality==5001
		outreg2 lrmilwnl year using TABLE_APPENDIX_A1_PanelA.csv, append se br  bdec(3) tdec(3) nocons 
		
					capture confirm file TABLE_APPENDIX_A1_PanelA.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelA.csv
		}
		
	reg  lrmilnar_col lrmilwnl  year yearsq if municipality==5001
		outreg2 lrmilwnl year yearsq using TABLE_APPENDIX_A1_PanelA.csv, append se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE_APPENDIX_A1_PanelA.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelA.csv
		}
		
	* Time series with violence 
	reg paratt   lrmilnar_col if municipality==5001
		outreg2 lrmilnar_col using TABLE_APPENDIX_A1_PanelA.csv, append  se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE_APPENDIX_A1_PanelA.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelA.csv
		}
		
	reg paratt   lrmilnar_col year if municipality==5001
		outreg2 lrmilnar_col year   using TABLE_APPENDIX_A1_PanelA.csv, append se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE_APPENDIX_A1_PanelA.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelA.csv
		}
	reg paratt   lrmilnar_col year yearsq if municipality==5001
		outreg2 lrmilnar_col year yearsq using TABLE_APPENDIX_A1_PanelA.csv, append se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE_APPENDIX_A1_PanelA.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelA.csv
		}
	reg gueratt   lrmilnar_col if municipality==5001
		outreg2 lrmilnar_col using TABLE_APPENDIX_A1_PanelA.csv, append se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE_APPENDIX_A1_PanelA.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelA.csv
		}
	reg gueratt   lrmilnar_col year if municipality==5001
		outreg2 lrmilnar_col year using TABLE_APPENDIX_A1_PanelA.csv, append se br  bdec(3) tdec(3) nocons 
		
					capture confirm file TABLE_APPENDIX_A1_PanelA.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelA.csv
		}
	reg gueratt   lrmilnar_col year yearsq if municipality==5001
		outreg2 lrmilnar_col year yearsq using TABLE_APPENDIX_A1_PanelA.csv, append se br  bdec(3) tdec(3) nocons 
		
	* Simple difference estimate 	
	xi:  xtivreg2 paratt  lnnewpop  lrmilnar_col if bases6==0, cluster(municipality) fe 
		outreg2 lrmilnar_col using TABLE_APPENDIX_A1_PanelB.csv, replace se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE_APPENDIX_A1_PanelB.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelB.csv
		}
	xi:  xtivreg2 paratt  lnnewpop  lrmilnar_col if bases6==1, cluster(municipality) fe 
		outreg2 lrmilnar_col using TABLE_APPENDIX_A1_PanelB.csv, append se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE_APPENDIX_A1_PanelB.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelB.csv
		}
	xi:  xtivreg2 gueratt lnnewpop  lrmilnar_col if bases6==0, cluster(municipality) fe 
		outreg2 lrmilnar_col using TABLE_APPENDIX_A1_PanelB.csv, append se br  bdec(3) tdec(3) nocons 
					capture confirm file TABLE_APPENDIX_A1_PanelB.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_A1_PanelB.csv
		}
		
	xi:  xtivreg2 gueratt  lnnewpop  lrmilnar_col if bases6==1, cluster(municipality) fe 
		outreg2 lrmilnar_col using TABLE_APPENDIX_A1_PanelB.csv, append se br  bdec(3) tdec(3) nocons 	

	
**********************************************
* Appendix Table 2: Descriptive statistics  
**********************************************

* for non-base regions 
#delimit; 
sum  paratt   govatt    gueratt   PAR_tot_hom GUER_tot_hom PAR_political_homicide  GUER_political_homicide
coca newpop captives weaponsops frkid operation_antinarcotics if bases6==0 & sample==1; 
sum sumtotcas7587v2_pop88 stdheight meanheight evercoca coca00 oil gp0003mediboth if year==2000 & bases6==0 & sample==1; 

* for base regions
#delimit; 
sum  paratt   govatt    gueratt   PAR_tot_hom GUER_tot_hom PAR_political_homicide  GUER_political_homicide
coca newpop captives weaponsops frkid operation_antinarcotics if bases6==1 & sample==1; 
sum sumtotcas7587v2_pop88 stdheight meanheight evercoca coca00 oil  gp0003mediboth if year==2000 & bases6==1 & sample==1; 

# delimit cr 

* for annual level variables 
sum rmilnar_col rmil_col rnar_col rmil_world_nolac rnar_world_nolac colmilexp_2000_bnusd if municipality==5001 & sample==1


	
*****************************************************************
* A3: estimating separate narcotics and military aid and lag effect
*****************************************************************

* use "bases_replication.dta", clear


* OLS narcotics aid on attacks
	xi: xtivreg2  paratt   bases6xlrnar_col lnnewpop i.year , cluster(municipality) fe 
	outreg2 bases6xlrnar_col  using TABLE_APPENDIX_3.csv, replace se  bdec(3) tdec(3) nocons br
						capture confirm file TABLE_APPENDIX_3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_3.csv
		}
		
foreach var of varlist  govatt   gueratt      {
	xi: xtivreg2  `var' bases6xlrnar_col lnnewpop i.year, cluster(municipality) fe 
	outreg2 bases6xlrnar_col  using TABLE_APPENDIX_3.csv, append se  bdec(3) tdec(3) nocons br
							capture confirm file TABLE_APPENDIX_3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_3.csv
		}
	}
	
* OLS military aid on attacks
	xi: xtivreg2  paratt   bases6xlrmil_col lnnewpop i.year , cluster(municipality) fe 
	outreg2 bases6xlrmil_col  using TABLE_APPENDIX_3.csv, append se  bdec(3) tdec(3) nocons br
	foreach var of varlist  govatt   gueratt      {
							capture confirm file TABLE_APPENDIX_3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_3.csv
		}
		}
		
	xi: xtivreg2  `var' bases6xlrmil_col lnnewpop i.year, cluster(municipality) fe 
	outreg2 bases6xlrmil_col  using TABLE_APPENDIX_3.csv, append se  bdec(3) tdec(3) nocons br

						capture confirm file TABLE_APPENDIX_3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_3.csv
		}
* OLS lag milnar  attacks 
tsset municipality year, yearly
	xi: xtivreg2  paratt   bases6xlrmilnar_col    L(1).bases6xlrmilnar_col   lnnewpop i.year , cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col  L.bases6xlrmilnar_col  using TABLE_APPENDIX_3.csv, append se  bdec(3) tdec(3) nocons br
	foreach var of varlist  govatt   gueratt   {
							capture confirm file TABLE_APPENDIX_3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_3.csv
		}

	xi: xtivreg2  `var'  bases6xlrmilnar_col    L(1).bases6xlrmilnar_col  lnnewpop i.year , cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col  L.bases6xlrmilnar_col using TABLE_APPENDIX_3.csv, append se  bdec(3) tdec(3) nocons br
	
						capture confirm file TABLE_APPENDIX_3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_3.csv
		}
		}
*  OLS on indicator outcomes 
	xi: xtivreg2  paratt_ind   bases6xlrmilnar_col lnnewpop i.year , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_3.csv, append se  bdec(3) tdec(3) nocons br
	
	foreach var of varlist  govatt_ind   gueratt_ind      {
							capture confirm file TABLE_APPENDIX_3.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_3.csv
		}
	xi: xtivreg2  `var' bases6xlrmilnar_col lnnewpop i.year, cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_3.csv, append se  bdec(3) tdec(3) nocons br
		}
	
	
		
****************************************************
* Appendix Table 4:  Negative Binomial
****************************************************

egen meantreat=mean(bases6xlrmilnar_col ), by(municipality)
egen meanivtreat=mean( bases6xlrmilwnl ), by(municipality)
egen meanlnpop=mean(lnnewpop  ), by(municipality )

gen dmtreat= bases6xlrmilnar_col -meantreat
gen dmivtreat=  bases6xlrmilwnl -meanivtreat
gen dmlnpop= lnnewpop-meanlnpop

/// Non-instrumented

set seed 11111 

xi: xtnbreg paratt  meantreat meanlnpop dmtreat dmlnpop  i.year,re vce(bootstrap, reps(100) ) 
outreg2   dmtreat using NB_hybrid_11111seed__CONTROL_MEANTREAT.csv, append se  bdec(3) tdec(3) nocons br addstat("Overdispersion", e(r), "p-value", e(p))
									capture confirm file NB_hybrid_11111seed__CONTROL_MEANTREAT.csv
    while _rc {      /* file does not exist! */
        capture confirm file NB_hybrid_11111seed__CONTROL_MEANTREAT.csv
		}
xi: xtnbreg govatt  meantreat meanlnpop dmtreat dmlnpop  i.year, re vce(bootstrap, reps(100) )
outreg2   dmtreat using NB_hybrid_11111seed__CONTROL_MEANTREAT.csv, append se  bdec(3) tdec(3) nocons br addstat("Overdispersion", e(r), "p-value", e(p))
									capture confirm file NB_hybrid_11111seed__CONTROL_MEANTREAT.csv
    while _rc {      /* file does not exist! */
        capture confirm file NB_hybrid_11111seed__CONTROL_MEANTREAT.csv
		}
xi: xtnbreg gueratt  meantreat meanlnpop dmtreat dmlnpop  i.year, re vce(bootstrap, reps(100) )
outreg2   dmtreat using NB_hybrid_11111seed__CONTROL_MEANTREAT.csv, append se  bdec(3) tdec(3) nocons br addstat("Overdispersion", e(r), "p-value", e(p))


/// Instrumented

***  First stage
xi:xtreg dmtreat dmivtreat dmlnpop i.year, fe cluster(municipality)
cap drop res
predict res, e

set seed 11111

**** Second stage with bootstrapped standard errors 
xi: xtnbreg paratt  meantreat meanlnpop  dmtreat dmlnpop  i.year res, re vce(bootstrap, reps(100) )
 outreg2   dmtreat using NB_hybrid_11111seed__CONTROL_MEANTREAT.csv, append se  bdec(3) tdec(3) nocons br addstat("Overdispersion", e(r), "p-value", e(p))
									capture confirm file NB_hybrid_11111seed__CONTROL_MEANTREAT.csv
    while _rc {      /* file does not exist! */
        capture confirm file NB_hybrid_11111seed__CONTROL_MEANTREAT.csv
		}
xi: xtnbreg govatt  meantreat meanlnpop dmtreat dmlnpop  i.year res, re vce(bootstrap, reps(100) )
 outreg2   dmtreat using NB_hybrid_11111seed__CONTROL_MEANTREAT.csv, append se  bdec(3) tdec(3) nocons br addstat("Overdispersion", e(r), "p-value", e(p))
									capture confirm file NB_hybrid_11111seed__CONTROL_MEANTREAT.csv
    while _rc {      /* file does not exist! */
        capture confirm file NB_hybrid_11111seed__CONTROL_MEANTREAT.csv
		}
xi: xtnbreg gueratt   meantreat meanlnpop dmtreat dmlnpop  i.year res, re vce(bootstrap, reps(100) )
 outreg2   dmtreat using NB_hybrid_11111seed__CONTROL_MEANTREAT.csv, append se  bdec(3) tdec(3) nocons br addstat("Overdispersion", e(r), "p-value", e(p))
	


*****************************************
* Appendix 5: spatial heterogeneity
*****************************************

	cap drop pGUERpres8890
	bys municipality: egen pGUERpres8890_step=max(pGUERpres) if year>=1988 & year<=1990
	bys municipality: egen pGUERpres8890=max(pGUERpres8890_step)
	
	foreach var of varlist pGUERpres8890 DELpres8890 {
	tab `var' bases6 if year ==1989 & sample==1
	}

	* ols restricting to places with and without paramilitary presence over 88 to 90
	xi: xtivreg2   paratt   lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & pGUERpres8890==1, cluster(municipality) fe first 
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5_guer_pres.csv, replace se br   bdec(3) tdec(3) nocons
										capture confirm file TABLE_APPENDIX_5_guer_pres.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5_guer_pres.csv
		}
		
	
	xi: xtivreg2  govatt  lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & pGUERpres8890==1, cluster(municipality) fe first
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5_guer_pres.csv, append se br  bdec(3) tdec(3) nocons
											capture confirm file TABLE_APPENDIX_5_guer_pres.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5_guer_pres.csv
		}
	
		
	xi: xtivreg2   paratt   lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & pGUERpres8890==0, cluster(municipality) fe first 
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5_guer_pres.csv, append se br   bdec(3) tdec(3) nocons
											capture confirm file TABLE_APPENDIX_5_guer_pres.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5_guer_pres.csv
		}
	
	xi: xtivreg2  govatt  lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & pGUERpres8890==0, cluster(municipality) fe first
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5_guer_pres.csv, append se br  bdec(3) tdec(3) nocons 
	

	* ols restricting to places with and without paramilitary presence over 88 to 90
	xi: xtivreg2   paratt   lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & DELpres8890==1, cluster(municipality) fe first 
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5.csv, replace se br   bdec(3) tdec(3) nocons
											capture confirm file TABLE_APPENDIX_5.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5.csv
		}
		
	xi: xtivreg2  govatt  lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & DELpres8890==1, cluster(municipality) fe first
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5.csv, append se br  bdec(3) tdec(3) nocons 

											capture confirm file TABLE_APPENDIX_5.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5.csv
		}
		
	xi: xtivreg2   paratt   lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & DELpres8890==0, cluster(municipality) fe first 
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5.csv, append  se br   bdec(3) tdec(3) nocons
												capture confirm file TABLE_APPENDIX_5.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5.csv
		}
		
	xi: xtivreg2  govatt  lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & DELpres8890==0, cluster(municipality) fe first
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5.csv, append se br  bdec(3) tdec(3) nocons 
												capture confirm file TABLE_APPENDIX_5.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5.csv
		}
		
	* OSL restricting to border and non-border regions
	xi: xtivreg2  paratt    bases6xlrmilnar_col  lnnewpop i.year if borbases6==1, cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using  TABLE_APPENDIX_5.csv, append se  bdec(3) tdec(3) nocons br 
	
	xi: xtivreg2  govatt  bases6xlrmilnar_col  lnnewpop i.year if borbases6==1, cluster(municipality) fe 
	outreg2    bases6xlrmilnar_col   using TABLE_APPENDIX_5.csv, append se  bdec(3) tdec(3) nocons br
	
											capture confirm file TABLE_APPENDIX_5.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5.csv
		}
		
	xi: xtivreg2  paratt    bases6xlrmilnar_col  lnnewpop i.year if borbases6v2==0, cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE_APPENDIX_5.csv, append se  bdec(3) tdec(3) nocons br 
	
	xi: xtivreg2  govatt  bases6xlrmilnar_col  lnnewpop i.year if borbases6v2==0, cluster(municipality) fe 
	outreg2    bases6xlrmilnar_col   using TABLE_APPENDIX_5.csv, append  se  bdec(3) tdec(3) nocons br
	
	
												capture confirm file TABLE_APPENDIX_5.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5.csv
		}
	* by regions producing and not producing coca
	xi: xtivreg2  paratt    bases6xlrmilnar_col  lnnewpop i.year if evercoca==0 , cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE_APPENDIX_5.csv, append se  bdec(3) tdec(3) nocons br 
	
	
	xi: xtivreg2  govatt  bases6xlrmilnar_col  lnnewpop i.year if evercoca==0, cluster(municipality) fe 
	outreg2    bases6xlrmilnar_col   using TABLE_APPENDIX_5.csv, append se  bdec(3) tdec(3) nocons br
	
												capture confirm file TABLE_APPENDIX_5.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5.csv
		}
		
	xi: xtivreg2  paratt    bases6xlrmilnar_col  lnnewpop i.year if evercoca==1 , cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE_APPENDIX_5.csv, append se  bdec(3) tdec(3) nocons br 

	xi: xtivreg2  govatt  bases6xlrmilnar_col  lnnewpop i.year if evercoca==1, cluster(municipality) fe 
	outreg2    bases6xlrmilnar_col   using TABLE_APPENDIX_5.csv, append se  bdec(3) tdec(3) nocons br
	

	
////////   GUERATT AS AN OUTCOME 

* ols restricting to places with and without paramilitary presence over 88 to 90
	xi: xtivreg2   gueratt   lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & DELpres8890==1, cluster(municipality) fe first 
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5_guer.csv, replace se br   bdec(3) tdec(3) nocons
									capture confirm file TABLE_APPENDIX_5_guer.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5_guer.csv
		}
	xi: xtivreg2   gueratt   lnnewpop  i.year  bases6xlrmilnar_col if sample==1 & DELpres8890==0, cluster(municipality) fe first 
	outreg2 bases6xlrmilnar_col  using TABLE_APPENDIX_5_guer.csv, append  se br   bdec(3) tdec(3) nocons

									capture confirm file TABLE_APPENDIX_5_guer.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5_guer.csv
		}
	* OSL restricting to border and non-border regions
	xi: xtivreg2  gueratt    bases6xlrmilnar_col  lnnewpop i.year if borbases6==1, cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using  TABLE_APPENDIX_5_guer.csv, append se  bdec(3) tdec(3) nocons br
										capture confirm file TABLE_APPENDIX_5_guer.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5_guer.csv
		}
	xi: xtivreg2  gueratt    bases6xlrmilnar_col  lnnewpop i.year if borbases6v2==0, cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE_APPENDIX_5_guer.csv, append se  bdec(3) tdec(3) nocons br 

									capture confirm file TABLE_APPENDIX_5_guer.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5_guer.csv
		}
	* by regions producing and not producing coca
	xi: xtivreg2  gueratt    bases6xlrmilnar_col  lnnewpop i.year if evercoca==0 , cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE_APPENDIX_5_guer.csv, append se  bdec(3) tdec(3) nocons br 
										capture confirm file TABLE_APPENDIX_5_guer.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_5_guer.csv
		}
	xi: xtivreg2  gueratt    bases6xlrmilnar_col  lnnewpop i.year if evercoca==1 , cluster(municipality) fe 
	outreg2   bases6xlrmilnar_col   using TABLE_APPENDIX_5_guer.csv, append se  bdec(3) tdec(3) nocons br 

	
***************************************************
* Table A6: Instrumenting with the average slope
**************************************************

	* 1st stage
	xi: xtivreg2 bases6xlrmilnar_col meanslopexlwnl lnnewpop i.year, cluster(municipality) fe first
	outreg2 meanslopexlwnl  using  TABLE_APPENDIX_6_FIRST_STAGE.csv, replace  se  bdec(3) tdec(3) nocons br

	* first stage without the interaction terms 
	xi: reg bases6  meanslope lnnewpop if year==2004,  cluster(municipality) 

	* gen meanslopexlrmilnar_col = meanslope*lrmilnar_col
	gen meanslopexlrmilwnl = meanslope*lrmilwnl


	*  IV usmil slope X nolac single  instrument 
	# delimit cr 
	xi: xtivreg2  paratt   (bases6xlrmilnar_col= meanslopexlrmilnar_col) lnnewpop i.year, cluster(municipality) fe first
	outreg2 bases6xlrmilnar_col  using  TABLE_APPENDIX_6.csv, replace se  bdec(3) tdec(3) nocons br
	foreach var of varlist gueratt   {
									capture confirm file TABLE_APPENDIX_6.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_6.csv
		}
	xi: xtivreg2  `var'  (bases6xlrmilnar_col= meanslopexlrmilnar_col) lnnewpop i.year, cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col  using  TABLE_APPENDIX_6.csv,  se br  bdec(3) tdec(3) nocons 
	}
	
								capture confirm file TABLE_APPENDIX_6.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_6.csv
	}
	* IV usmil slope X nolac as instrument (ie, the double instrument)
	# delimit cr 
	xi: xtivreg2  paratt   (bases6xlrmilnar_col= meanslopexlrmilwnl) lnnewpop i.year, cluster(municipality) fe first
	outreg2 bases6xlrmilnar_col  using  TABLE_APPENDIX_6.csv,  se  bdec(3) tdec(3) nocons br
	foreach var of varlist  gueratt   {
									capture confirm file TABLE_APPENDIX_6.csv
    while _rc {      /* file does not exist! */
        capture confirm file TABLE_APPENDIX_6.csv
		}
	xi: xtivreg2  `var'  (bases6xlrmilnar_col= meanslopexlrmilwnl) lnnewpop i.year, cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col  using  TABLE_APPENDIX_6.csv,  se br  bdec(3) tdec(3) nocons 
	}
	
	
************************************************	
***  TABLE A.7: Controlling for Endogenous Base 
************************************************

	xi: xtivreg2  paratt    bases6xlrmilnar_col  endogbaseonly   lnnewpop i.year , cluster(municipality) fe 
	outreg2 bases6xlrmilnar_col endogbaseonly   using Table_AVII_endogbase2.csv, replace se  bdec(3) tdec(3) nocons br
	foreach var of varlist      govatt gueratt  {
							capture confirm file Table_AVII_endogbase2.csv
    while _rc {      /* file does not exist! */
        capture confirm file Table_AVII_endogbase2.csv
		}
	xi: xtivreg2  `var' bases6xlrmilnar_col    endogbaseonly lnnewpop i.year , cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col endogbaseonly    using  Table_AVII_endogbase2.csv, append se  bdec(3) tdec(3) nocons br
	}
							capture confirm file Table_AVII_endogbase2.csv
    while _rc {      /* file does not exist! */
        capture confirm file Table_AVII_endogbase2.csv
		}
	foreach var of varlist    paratt  govatt  gueratt  {
								capture confirm file Table_AVII_endogbase2.csv
    while _rc {      /* file does not exist! */
        capture confirm file Table_AVII_endogbase2.csv
		}
	xi: xtivreg2  `var' bases6xlrmilnar_col    endogbaseexpxpost2001  lnnewpop i.year , cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col  endogbaseexpxpost2001  using  Table_AVII_endogbase2.csv, append se  bdec(3) tdec(3) nocons br
	}
							capture confirm file Table_AVII_endogbase2.csv
    while _rc {      /* file does not exist! */
        capture confirm file Table_AVII_endogbase2.csv
		}
	foreach var of varlist    paratt    govatt  gueratt {
	xi: xtivreg2  `var' bases6xlrmilnar_col    endogbaseonly   endogbaseexpxpost2001  lnnewpop i.year , cluster(municipality) fe 
	outreg2  bases6xlrmilnar_col   endogbaseonly   endogbaseexpxpost2001  using  Table_AVII_endogbase2.csv, append se  bdec(3) tdec(3) nocons br
	}
	
	
log close


